from onegov.onboarding.models.assistant import (
    Assistant,
    DefaultAssistant,
    Step
)
from onegov.onboarding.models.town_assistant import TownAssistant

__all__ = [
    'Assistant',
    'DefaultAssistant',
    'Step',
    'TownAssistant'
]
